@@ -1,8 +1,7 @@
-# Copyright 2017-2021 Laszlo Attila Toth
+# Copyright 2017-2022 Laszlo Attila Toth
 # Distributed under the terms of the Apache License, Version 2.0
 
 import types
-import typing
 
 from dewi_core.command import Command
 from dewi_core.loader.context import Context
@@ -10,13 +9,13 @@ from dewi_core.loader.plugin import Plugin
 
 
 class CommandPlugin(Plugin):
-    command: typing.Type[Command]
+    command: type[Command]
 
     def load(self, c: Context):
         c.commands.register_class(self.command)
 
     @classmethod
-    def create(cls, command: typing.Type[Command]) -> typing.Type[Plugin]:
+    def create(cls, command: type[Command]) -> type[Plugin]:
         class_name = command.__name__
         if class_name.endswith('Command'):
             class_name = class_name[:-len('Command')]
