@@ -1,9 +1,8 @@
-# Copyright 2018-2021 Laszlo Attila Toth
+# Copyright 2018-2022 Laszlo Attila Toth
 # Distributed under the terms of the Apache License, Version 2.0
 
 import os
 import sys
-import typing
 
 import yaml
 
@@ -12,12 +11,11 @@ try:
 except ImportError:
     from yaml import Loader
 
-
 if os.environ.get('DEWI_YAML_WITH_ALIASES', '0') == '0':
     yaml.Dumper.ignore_aliases = lambda *args: True
 
 
-def save_to_yaml(cfg, output_file: typing.Optional[str] = None):
+def save_to_yaml(cfg, output_file: str | None = None):
     if not output_file or output_file == '-':
         yaml.dump(cfg, stream=sys.stdout, indent=4, default_flow_style=False)
     else:
